# InlineResponse2008

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**offset** | **str** | Pagination offset for next page | [optional] 
**comments** | [**list[InlineResponse2008Comments]**](InlineResponse2008Comments.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

